=====
pyqna
=====

.. image:: https://img.shields.io/travis/programmer290399/pyqna.svg
        :target: https://travis-ci.org/programmer290399/pyqna

.. image:: https://img.shields.io/pypi/v/pyqna.svg
        :target: https://pypi.python.org/pypi/pyqna


A simple python package for question answering

* Free software: 3-clause BSD license
* Documentation: https://programmer290399.github.io/pyqna.

Features
--------

* TODO
